[Python-checkins] cpython (merge 3.3 -> default): #18798: merge typo fix from 3.3 and also use two unused variables.

ezio.melotti python-checkins at python.org
Fri Aug 23 22:09:56 CEST 2013


http://hg.python.org/cpython/rev/0f8f5fd6e712
changeset:   85352:0f8f5fd6e712
parent:      85349:64678369c4d0
parent:      85351:41c90b8f49d9
user:        Ezio Melotti <ezio.melotti at gmail.com>
date:        Fri Aug 23 23:09:32 2013 +0300
summary:
  #18798: merge typo fix from 3.3 and also use two unused variables.

files:
  Lib/test/test_fcntl.py |  6 +++++-
  1 files changed, 5 insertions(+), 1 deletions(-)


diff --git a/Lib/test/test_fcntl.py b/Lib/test/test_fcntl.py
--- a/Lib/test/test_fcntl.py
+++ b/Lib/test/test_fcntl.py
@@ -8,7 +8,7 @@
 import unittest
 from test.support import verbose, TESTFN, unlink, run_unittest, import_module
 
 # Skip test if no fnctl module.
 fcntl = import_module('fcntl')
 
 
@@ -70,7 +70,11 @@
         # again, but pass the file rather than numeric descriptor
         self.f = open(TESTFN, 'wb')
         rv = fcntl.fcntl(self.f, fcntl.F_SETFL, os.O_NONBLOCK)
+        if verbose:
+            print('Status from fcntl with O_NONBLOCK: ', rv)
         rv = fcntl.fcntl(self.f, fcntl.F_SETLKW, lockdata)
+        if verbose:
+            print('String from fcntl with F_SETLKW: ', repr(rv))
         self.f.close()
 
     def test_fcntl_bad_file(self):
@@ -8,7 +8,7 @@
 from test.support import verbose, TESTFN, unlink, run_unittest, import_module
 
-# Skip test if no fnctl module.
+# Skip test if no fcntl module.
 fcntl = import_module('fcntl')
 

-- 
Repository URL: http://hg.python.org/cpython


More information about the Python-checkins mailing list